/*
 * Copyright 2010 Google Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except
 * in compliance with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License
 * is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express
 * or implied. See the License for the specific language governing permissions and limitations under
 * the License.
 */
/*
 * This file was generated.
 *  with google-apis-code-generator 1.4.1 (build: 2013-08-14 15:32:06 UTC)
 *  on 2013-08-19 at 21:06:08 UTC 
 */

package com.google.api.services.audit;

import com.google.api.client.googleapis.GoogleUtils;
import com.google.api.client.googleapis.services.AbstractGoogleClientRequest;
import com.google.api.client.googleapis.services.GoogleClientRequestInitializer;
import com.google.api.client.googleapis.services.json.AbstractGoogleJsonClient;
import com.google.api.client.http.HttpRequestInitializer;
import com.google.api.client.http.HttpTransport;
import com.google.api.client.json.JsonFactory;
import com.google.api.client.json.JsonObjectParser;
import com.google.api.client.json.JsonString;
import com.google.common.base.Preconditions;

/**
 * Service definition for Audit (v1).
 *
 * <p>
 * Lets you access user activities in your enterprise made through various applications.
 * </p>
 *
 * <p>
 * For more information about this service, see the
 * <a href="https://developers.google.com/google-apps/admin-audit/get_started" target="_blank">API Documentation</a>
 * </p>
 *
 * <p>
 * This service uses {@link AuditRequestInitializer} to initialize global parameters via its
 * {@link Builder}.
 * </p>
 *
 * <p>
 * Upgrade warning: this class now extends {@link AbstractGoogleJsonClient}, whereas in prior
 * version 1.8 it extended {@link com.google.api.client.googleapis.services.GoogleClient}.
 * </p>
 *
 * @since 1.3
 * @author Google, Inc.
 */
@SuppressWarnings("javadoc")
public class Audit extends AbstractGoogleJsonClient {

  // Note: Leave this static initializer at the top of the file.
  static {
    Preconditions.checkState(GoogleUtils.VERSION.equals("1.13.2-beta"),
        "You are currently running with version %s of google-api-client. " +
        "You need version 1.13.2-beta of google-api-client to run version " +
        "1.13.2-beta of the Enterprise Audit API library.", GoogleUtils.VERSION);
  }

  /**
   * The default encoded root URL of the service. This is determined when the library is generated
   * and normally should not be changed.
   *
   * @since 1.7
   */
  public static final String DEFAULT_ROOT_URL = "https://www.googleapis.com/";

  /**
   * The default encoded service path of the service. This is determined when the library is
   * generated and normally should not be changed.
   *
   * @since 1.7
   */
  public static final String DEFAULT_SERVICE_PATH = "apps/reporting/audit/v1/";

  /**
   * The default encoded base URL of the service. This is determined when the library is generated
   * and normally should not be changed.
   * @deprecated (scheduled to be removed in 1.13)
   */
  @Deprecated
  public static final String DEFAULT_BASE_URL = DEFAULT_ROOT_URL + DEFAULT_SERVICE_PATH;

  /**
   * Constructor.
   *
   * <p>
   * Use {@link Builder} if you need to specify any of the optional parameters.
   * </p>
   *
   * @param transport HTTP transport
   * @param jsonFactory JSON factory
   * @param httpRequestInitializer HTTP request initializer or {@code null} for none
   * @since 1.7
   */
  public Audit(HttpTransport transport, JsonFactory jsonFactory,
      HttpRequestInitializer httpRequestInitializer) {
    super(transport,
        jsonFactory,
        DEFAULT_ROOT_URL,
        DEFAULT_SERVICE_PATH,
        httpRequestInitializer,
        false);
  }

  /**
   * @param transport HTTP transport
   * @param httpRequestInitializer HTTP request initializer or {@code null} for none
   * @param rootUrl root URL of the service
   * @param servicePath service path
   * @param jsonObjectParser JSON object parser
   * @param googleClientRequestInitializer Google request initializer or {@code null} for none
   * @param applicationName application name to be sent in the User-Agent header of requests or
   *        {@code null} for none
   * @param suppressPatternChecks whether discovery pattern checks should be suppressed on required
   *        parameters
   */
  Audit(HttpTransport transport,
      HttpRequestInitializer httpRequestInitializer,
      String rootUrl,
      String servicePath,
      JsonObjectParser jsonObjectParser,
      GoogleClientRequestInitializer googleClientRequestInitializer,
      String applicationName,
      boolean suppressPatternChecks) {
    super(transport,
        httpRequestInitializer,
        rootUrl,
        servicePath,
        jsonObjectParser,
        googleClientRequestInitializer,
        applicationName,
        suppressPatternChecks);
  }

  @Override
  protected void initialize(AbstractGoogleClientRequest<?> httpClientRequest) throws java.io.IOException {
    super.initialize(httpClientRequest);
  }

  /**
   * An accessor for creating requests from the Activities collection.
   *
   * <p>The typical use is:</p>
   * <pre>
   *   {@code Audit audit = new Audit(...);}
   *   {@code Audit.Activities.List request = audit.activities().list(parameters ...)}
   * </pre>
   *
   * @return the resource collection
   */
  public Activities activities() {
    return new Activities();
  }

  /**
   * The "activities" collection of methods.
   */
  public class Activities {

    /**
     * Retrieves a list of activities for a specific customer and application.
     *
     * Create a request for the method "activities.list".
     *
     * This request holds the parameters needed by the the audit server.  After setting any optional
     * parameters, call the {@link List#execute()} method to invoke the remote operation.
     *
     * @param customerId Represents the customer who is the owner of target object on which action was performed.
     * @param applicationId Application ID of the application on which the event was performed.
     * @return the request
     */
    public List list(String customerId, Long applicationId) throws java.io.IOException {
      List result = new List(customerId, applicationId);
      initialize(result);
      return result;
    }

    public class List extends AuditRequest<com.google.api.services.audit.model.Activities> {

      private static final String REST_PATH = "{customerId}/{applicationId}";

      private final java.util.regex.Pattern CUSTOMERID_PATTERN =
          java.util.regex.Pattern.compile("C.+");

      /**
       * Retrieves a list of activities for a specific customer and application.
       *
       * Create a request for the method "activities.list".
       *
       * This request holds the parameters needed by the the audit server.  After setting any optional
       * parameters, call the {@link List#execute()} method to invoke the remote operation. <p> {@link
       * List#initialize(AbstractGoogleClientRequest)} must be called to initialize this instance
       * immediately after invoking the constructor. </p>
       *
       * @param customerId Represents the customer who is the owner of target object on which action was performed.
       * @param applicationId Application ID of the application on which the event was performed.
       * @since 1.13
       */
      protected List(String customerId, Long applicationId) {
        super(Audit.this, "GET", REST_PATH, null, com.google.api.services.audit.model.Activities.class);
        this.customerId = Preconditions.checkNotNull(customerId, "Required parameter customerId must be specified.");
        if (!getSuppressPatternChecks()) {
          Preconditions.checkArgument(CUSTOMERID_PATTERN.matcher(customerId).matches(),
              "Parameter customerId must conform to the pattern " +
              "C.+");
        }
        this.applicationId = Preconditions.checkNotNull(applicationId, "Required parameter applicationId must be specified.");
      }

      @Override
      public com.google.api.client.http.HttpResponse executeUsingHead() throws java.io.IOException {
        return super.executeUsingHead();
      }

      @Override
      public com.google.api.client.http.HttpRequest buildHttpRequestUsingHead() throws java.io.IOException {
        return super.buildHttpRequestUsingHead();
      }

      @Override
      public List setAlt(String alt) {
        return (List) super.setAlt(alt);
      }

      @Override
      public List setFields(String fields) {
        return (List) super.setFields(fields);
      }

      @Override
      public List setKey(String key) {
        return (List) super.setKey(key);
      }

      @Override
      public List setOauthToken(String oauthToken) {
        return (List) super.setOauthToken(oauthToken);
      }

      @Override
      public List setPrettyPrint(Boolean prettyPrint) {
        return (List) super.setPrettyPrint(prettyPrint);
      }

      @Override
      public List setQuotaUser(String quotaUser) {
        return (List) super.setQuotaUser(quotaUser);
      }

      @Override
      public List setUserIp(String userIp) {
        return (List) super.setUserIp(userIp);
      }

      /** Represents the customer who is the owner of target object on which action was performed. */
      @com.google.api.client.util.Key
      private String customerId;

      /** Represents the customer who is the owner of target object on which action was performed.
       */
      public String getCustomerId() {
        return customerId;
      }

      /** Represents the customer who is the owner of target object on which action was performed. */
      public List setCustomerId(String customerId) {
        if (!getSuppressPatternChecks()) {
          Preconditions.checkArgument(CUSTOMERID_PATTERN.matcher(customerId).matches(),
              "Parameter customerId must conform to the pattern " +
              "C.+");
        }
        this.customerId = customerId;
        return this;
      }

      /** Application ID of the application on which the event was performed. */
      @com.google.api.client.util.Key
      private Long applicationId;

      /** Application ID of the application on which the event was performed.
       */
      public Long getApplicationId() {
        return applicationId;
      }

      /** Application ID of the application on which the event was performed. */
      public List setApplicationId(Long applicationId) {
        this.applicationId = applicationId;
        return this;
      }

      /** Email address of the user who performed the action. */
      @com.google.api.client.util.Key
      private String actorEmail;

      /** Email address of the user who performed the action.
       */
      public String getActorEmail() {
        return actorEmail;
      }

      /** Email address of the user who performed the action. */
      public List setActorEmail(String actorEmail) {
        this.actorEmail = actorEmail;
        return this;
      }

      /**
     * Application ID of the application which interacted on behalf of the user while performing the
     * event.
     */
      @com.google.api.client.util.Key
      private Long actorApplicationId;

      /** Application ID of the application which interacted on behalf of the user while performing the
     event.
       */
      public Long getActorApplicationId() {
        return actorApplicationId;
      }

      /**
     * Application ID of the application which interacted on behalf of the user while performing the
     * event.
     */
      public List setActorApplicationId(Long actorApplicationId) {
        this.actorApplicationId = actorApplicationId;
        return this;
      }

      /** IP Address of host where the event was performed. Supports both IPv4 and IPv6 addresses. */
      @com.google.api.client.util.Key
      private String actorIpAddress;

      /** IP Address of host where the event was performed. Supports both IPv4 and IPv6 addresses.
       */
      public String getActorIpAddress() {
        return actorIpAddress;
      }

      /** IP Address of host where the event was performed. Supports both IPv4 and IPv6 addresses. */
      public List setActorIpAddress(String actorIpAddress) {
        this.actorIpAddress = actorIpAddress;
        return this;
      }

      /** Type of the caller. */
      @com.google.api.client.util.Key
      private String caller;

      /** Type of the caller.
       */
      public String getCaller() {
        return caller;
      }

      /** Type of the caller. */
      public List setCaller(String caller) {
        this.caller = caller;
        return this;
      }

      /** Number of activity records to be shown in each page. */
      @com.google.api.client.util.Key
      private Integer maxResults;

      /** Number of activity records to be shown in each page.

     [minimum: 1] [maximum: 1000]
       */
      public Integer getMaxResults() {
        return maxResults;
      }

      /** Number of activity records to be shown in each page. */
      public List setMaxResults(Integer maxResults) {
        this.maxResults = maxResults;
        return this;
      }

      /** Name of the event being queried. */
      @com.google.api.client.util.Key
      private String eventName;

      /** Name of the event being queried.
       */
      public String getEventName() {
        return eventName;
      }

      /** Name of the event being queried. */
      public List setEventName(String eventName) {
        this.eventName = eventName;
        return this;
      }

      /** Return events which occured at or after this time. */
      @com.google.api.client.util.Key
      private String startTime;

      /** Return events which occured at or after this time.
       */
      public String getStartTime() {
        return startTime;
      }

      /** Return events which occured at or after this time. */
      public List setStartTime(String startTime) {
        this.startTime = startTime;
        return this;
      }

      /** Return events which occured at or before this time. */
      @com.google.api.client.util.Key
      private String endTime;

      /** Return events which occured at or before this time.
       */
      public String getEndTime() {
        return endTime;
      }

      /** Return events which occured at or before this time. */
      public List setEndTime(String endTime) {
        this.endTime = endTime;
        return this;
      }

      /** Next page URL. */
      @com.google.api.client.util.Key
      private String continuationToken;

      /** Next page URL.
       */
      public String getContinuationToken() {
        return continuationToken;
      }

      /** Next page URL. */
      public List setContinuationToken(String continuationToken) {
        this.continuationToken = continuationToken;
        return this;
      }

    }

  }

  /**
   * Builder for {@link Audit}.
   *
   * <p>
   * Implementation is not thread-safe.
   * </p>
   *
   * @since 1.3.0
   */
  public static final class Builder extends AbstractGoogleJsonClient.Builder {

    /**
     * Returns an instance of a new builder.
     *
     * @param transport HTTP transport
     * @param jsonFactory JSON factory
     * @param httpRequestInitializer HTTP request initializer or {@code null} for none
     * @since 1.7
     */
    public Builder(HttpTransport transport, JsonFactory jsonFactory,
        HttpRequestInitializer httpRequestInitializer) {
      super(
          transport,
          jsonFactory,
          DEFAULT_ROOT_URL,
          DEFAULT_SERVICE_PATH,
          httpRequestInitializer,
          false);
    }

    /** Builds a new instance of {@link Audit}. */
    @Override
    public Audit build() {
      return new Audit(getTransport(),
          getHttpRequestInitializer(),
          getRootUrl(),
          getServicePath(),
          getObjectParser(),
          getGoogleClientRequestInitializer(),
          getApplicationName(),
          getSuppressPatternChecks());
    }

    @Override
    public Builder setRootUrl(String rootUrl) {
      return (Builder) super.setRootUrl(rootUrl);
    }

    @Override
    public Builder setServicePath(String servicePath) {
      return (Builder) super.setServicePath(servicePath);
    }

    @Override
    public Builder setHttpRequestInitializer(HttpRequestInitializer httpRequestInitializer) {
      return (Builder) super.setHttpRequestInitializer(httpRequestInitializer);
    }

    @Override
    public Builder setApplicationName(String applicationName) {
      return (Builder) super.setApplicationName(applicationName);
    }

    @Override
    public Builder setSuppressPatternChecks(boolean suppressPatternChecks) {
      return (Builder) super.setSuppressPatternChecks(suppressPatternChecks);
    }

    /**
     * Set the {@link AuditRequestInitializer}.
     *
     * @since 1.12
     */
    public Builder setAuditRequestInitializer(
        AuditRequestInitializer auditRequestInitializer) {
      return (Builder) super.setGoogleClientRequestInitializer(auditRequestInitializer);
    }

    @Override
    public Builder setGoogleClientRequestInitializer(
        GoogleClientRequestInitializer googleClientRequestInitializer) {
      return (Builder) super.setGoogleClientRequestInitializer(googleClientRequestInitializer);
    }
  }
}
